==> haskell-attoparsec-0.13.2.3-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec
version:              0.13.2.3
visibility:           public
id:                   attoparsec-0.13.2.3-6p25usB4Z80LvzCYs9NN4A
key:                  attoparsec-0.13.2.3-6p25usB4Z80LvzCYs9NN4A
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  2ff96c3d31bd276aa112a5a8d1e9f7fb
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet
    Data.Attoparsec.ByteString.Internal
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-8.8.3/site-local/attoparsec-0.13.2.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/attoparsec-0.13.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/attoparsec-0.13.2.3
hs-libraries:         HSattoparsec-0.13.2.3-6p25usB4Z80LvzCYs9NN4A
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 scientific-0.3.6.2-6irdu2VdjjMJDmbJHneA4J
    text-1.2.4.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.13.2.3-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec
version:              0.13.2.3
visibility:           public
id:                   attoparsec-0.13.2.3-Ly3opcHExc4FDAnpaswQZX
key:                  attoparsec-0.13.2.3-Ly3opcHExc4FDAnpaswQZX
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  20d32951c00207985585d6ac59943fef
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet
    Data.Attoparsec.ByteString.Internal
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-8.8.3/site-local/attoparsec-0.13.2.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/attoparsec-0.13.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/attoparsec-0.13.2.3
hs-libraries:         HSattoparsec-0.13.2.3-Ly3opcHExc4FDAnpaswQZX
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 scientific-0.3.6.2-HwSise45C5vHNs50sfVp6t
    text-1.2.4.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
